# freeAI
this is a python package to use the completely free chatGPT and more models.
(This package is under development. There may be a bugs)

| SITE | model | how to use? | messages history |
| ---- | ----- | ----------- | ---------------- |
| [alpaca-7B](https://us-central1-arched-keyword-306918.cloudfunctions.net/) | alpaca | [use](freeAI/alpaca7b/README.md) | :x: |
| [mishalsGPT](https://mishalsgpt.vercel.app) | GPT-3.5-turbo | [use](freeAI/mishalsgpt/README.md) | :white_check_mark: |
| [miniGPT](https://mflsf.aitianhu.fun) | GPT-3.5-turbo | [use](freeAI/minigpt/README.md) | :x:
| [gpt-4](http://124.222.157.84:8012) | GPT-4 / [check more](freeAI/gpt4/README.md#models) | [use](freeAI/gpt4/README.md) | :white_check_mark: |
| [avaGPT](https://codelink.io/) | GPT-4 | [use](freeAI/avagpt/README.md) | :white_check_mark: |
| [lockGPT](http://lockchat.app) | GPT-3.5-turbo | [use](freeAI/lockgpt/README.md) | :white_check_mark: |
| [AIchatOS](https://aichatos.cloud) | GPT-3.5-turbo | [use](freeAI/aichatos/README.md) | :x: |
## Installation
```sh
git clone https://github.com/HotDrify/freeAI
cd freeAI
python3 setup.py install
```
done!

## task list
- [x] add GPT 3.5-turbo
- [x] add alpaca 7B
- [x] add GPT 4
- [x] add messages history
- [ ] add image AI

## status check (soon)
> when is it updated? > once every **~30 min**. [go to actions](https://github.com/HotDrify/freeAI/actions)
